@@ -21,7 +21,6 @@ class SettingsDialog(QDialog):
         self.lemmatization = QCheckBox("Use lemmatization (Requires restart to take effect)")
         self.lemmatization.setToolTip("Lemmatization means to get the original form of words."
             + "\nFor example, 'books' will be converted to 'book' during lookup if this option is set.")
-        self.remove_spaces = QCheckBox("Remove generated spaces when exporting to Anki (Japanese, Chinese)")
         self.target_language = QComboBox()
         self.deck_name = QComboBox()
         self.tags = QLineEdit()
@@ -132,7 +131,6 @@ If you find this tool useful, you can donate to these projects.
         self.tab1.layout.addRow(QLabel("Dictionary source 1"), self.dict_source)
         self.tab1.layout.addRow(QLabel("Dictionary source 2"), self.dict_source2)
         self.tab1.layout.addRow(QLabel("Google translate: To"), self.gtrans_lang)
-        self.tab1.layout.addRow(self.remove_spaces)
         self.tab1.layout.addRow(self.importdict)
 
 
@@ -165,7 +163,6 @@ If you find this tool useful, you can donate to these projects.
     def setupAutosave(self):
         self.allow_editing.clicked.connect(self.syncSettings)
         self.lemmatization.clicked.connect(self.syncSettings)
-        self.remove_spaces.clicked.connect(self.syncSettings)
         self.forvo.clicked.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.syncSettings)
         self.dict_source.currentTextChanged.connect(self.loadDict2Options)
@@ -200,11 +197,6 @@ If you find this tool useful, you can donate to these projects.
         dicts = getDictsForLang(code[self.target_language.currentText()])
         self.dict_source.addItems(dicts)
 
-        if code[self.target_language.currentText()] in ["ja", "zh"]:
-            self.remove_spaces.setCheckable(True)
-        else:
-            self.remove_spaces.setCheckable(False)
-
     def loadDict2Options(self):
         curtext = self.dict_source2.currentText()
         self.dict_source2.blockSignals(True)
@@ -225,7 +217,6 @@ If you find this tool useful, you can donate to these projects.
         self.allow_editing.setChecked(self.settings.value("allow_editing", True, type=bool))
         self.lemmatization.setChecked(self.settings.value("lemmatization", True, type=bool))
         self.orientation.setCurrentText(self.settings.value("orientation", "Vertical"))
-        self.remove_spaces.setChecked(self.settings.value("remove_spaces", True, type=bool))
         self.text_scale.setValue(self.settings.value("text_scale", 100, type=int))
         self.target_language.setCurrentText(self.settings.value("target_language"))
         self.loadDictionaries()
@@ -335,7 +326,6 @@ If you find this tool useful, you can donate to these projects.
         self.settings.setValue("target_language", self.target_language.currentText())
         self.settings.setValue("dict_source", self.dict_source.currentText())
         self.settings.setValue("dict_source2", self.dict_source2.currentText())
-        self.settings.setValue("remove_spaces", self.remove_spaces.isChecked())
         self.settings.setValue("gtrans_lang", self.gtrans_lang.currentText())
         self.settings.setValue("anki_api", self.anki_api.text())
         self.settings.setValue("host", self.host.text())
